=====================
Modules documentation
=====================

Database
--------
.. module:: neomodel.util
.. autoclass:: neomodel.util.Database
  :members:
  :undoc-members:
  
Core
----
.. automodule:: neomodel.core
  :members:

.. _semistructurednode_doc:

``SemiStructuredNode``
^^^^^^^^^^^^^^^^^^^^^^
.. autoclass:: neomodel.contrib.SemiStructuredNode

Properties
----------
.. automodule:: neomodel.properties
  :members:
  :show-inheritance:

Spatial Properties & Datatypes
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: neomodel.contrib.spatial_properties
  :members:
  :show-inheritance:

Relationships
-------------
.. automodule:: neomodel.relationship
  :members:
  :show-inheritance:

.. automodule:: neomodel.relationship_manager
  :members:
  :show-inheritance:

.. automodule:: neomodel.cardinality
  :members:
  :show-inheritance:

Match
-----
.. module:: neomodel.match
.. autoclass:: neomodel.match.BaseSet
   :members:
   :undoc-members:
.. autoclass:: neomodel.match.NodeSet
   :members:
   :undoc-members:
.. autoclass:: neomodel.match.Traversal
   :members:
   :undoc-members:


Exceptions
----------

.. automodule:: neomodel.exceptions
   :members:
   :undoc-members:
   :show-inheritance:
